config

package
v0.0.0-...-eaccc95 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 4, 2018 License: MIT Imports: 11 Imported by: 0

README

Config

Parses a docker-compose v3 syntax config and outputs it into a fsouza/go-dockerclient compatible format. The compose file parsing code is greatly inspired by github.com/kubernetes/kompose's loader.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	types.Config
	Services []Service
}

Config represents a Docker Compose v3 configuration

func LoadConfig

func LoadConfig(filename string) (*Config, error)

func (*Config) Validate

func (c *Config) Validate() error

Validate checks all required parameters are defined.

type Service

type Service types.ServiceConfig

Service represents a Service in a Docker Compose v3 file.

func (Service) CreateContainerOptions

func (s Service) CreateContainerOptions() (docker.CreateContainerOptions, error)

CreateContainerOptions translates the Service configuration to an fsouza/go-dockerclient CreateContainerOptions type.

Jump to